#include "PCA9685.h"


/******************************************************************************
function:	
	Set duty cycle
parameter	:
	channel : Channel number
	on      : Drive output turn-on time 
	off     : PWM duty cycle 
******************************************************************************/
void PCA9685_setPWM(UBYTE channel, UWORD on, UWORD off)
{
	UBYTE value[4];
	value[0] = on & 0xFF;
	value[1] = on >> 8;
	value[2] = off & 0xFF;
	value[3] = off >> 8;
	
	user_i2c_write(1, LED0_ON_L  + 4 * channel, &value[0], 1);
	user_i2c_write(1, LED0_ON_H  + 4 * channel, &value[1], 1);
	user_i2c_write(1, LED0_OFF_L + 4 * channel, &value[2], 1);
	user_i2c_write(1, LED0_OFF_H + 4 * channel, &value[3], 1);
	
}




/******************************************************************************
function:	
	PCA9685 initialization 
******************************************************************************/
void Init_PCA9685()
{
	UDOUBLE prescaleval;
	UBYTE oldmode;
	
	UBYTE value;
	
	value = 0x00;
	user_i2c_write(1, MODE1, &value, 1);

	prescaleval = 25000000;   
	prescaleval /= 4096;      
	prescaleval /= PCA9685_PWM_Hz;
	prescaleval -= 1.0;
	
	prescaleval=prescaleval+3;
	
	user_i2c_read(1, MODE1, &oldmode, 1);
	
	value = (oldmode & 0x7F) | 0x10;
	user_i2c_write(1, MODE1, &value, 1);

	value = prescaleval;
	user_i2c_write(1, PRESCALE, &value, 1);

	value = oldmode;
	user_i2c_write(1, MODE1, &value, 1);

	DEV_Delay_ms(200);

	value = oldmode | 0x80;
	user_i2c_write(1, MODE1, &value, 1);

	value = 0x04;
	user_i2c_write(1, MODE2, &value, 1);

    PCA9685_setPWM(0, 0, 0);
    PCA9685_setPWM(1, 0, 0);
}
