#include <stdio.h>      //printf()
#include <stdlib.h>     //exit()
#include <signal.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <fcntl.h>

#include "DEV_Config.h"
#include "PCA9685.h"
#include "FT5436.h"

void  Handler(int signo)
{
	//System Exit
    printf("\r\nHandler:Program stop\r\n"); \
	
	bcm2835_i2c_setSlaveAddress(PCA9685_Addr);
	UBYTE value = 0x00;	
	user_i2c_write(1, MODE2, &value, 1);

    DEV_ModuleExit();
    exit(0);
}


int main(int argc, char **argv)
{
	int fd;

	if (DEV_ModuleInit() == 1)
	{
		return 1;
	}

    //Exception handling:ctrl + c
    signal(SIGINT, Handler);
	
	//set for PCA9685
	bcm2835_i2c_setSlaveAddress(PCA9685_Addr);

    //PCA9685 initialization
	Init_PCA9685();

	//Warm front light,0~4095
    PCA9685_setPWM(0, 0, 2048); 
	//Cold front light,0~4095
    PCA9685_setPWM(1, 0, 2048);
	
	//set for FT5436
	bcm2835_i2c_setSlaveAddress(FT5436_Addr);
	
	//FT5436 initialization
	FT5436_Init();
	
	//init file FIFO
	if(access("/home/pi/FIFO",F_OK))
	{
		int ret = mkfifo("/home/pi/FIFO",0777);
		if(ret == -1)
		{
			printf("mkfifo error!\n");
			exit(0);
		}
	}
	fd = open("/home/pi/FIFO",O_RDWR);
	if(fd == -1)
	{
		printf("open error!\n");
		exit(0);
	}
	printf("Start to read the touch point.\r\n");
	
	//Start to read the pannel data and then write to FIFO
	while(1)
	{
		if(bcm2835_gpio_lev(FT5436_IRQ_PIN) == 0)
		{
			
			FT5436_Read_To_FIFO(fd);
		}
		else
		{
			//in idle state
		}		
	}

	DEV_ModuleExit();
    return 0;
}